@@ -303,10 +303,10 @@ plot(nEdgesActive,xlab='timestep',ylab='number of active edges')
 ### code chunk number 33: file_spells
 ###################################################
 vertexData <-read.table(system.file('extdata/cls33_10_16_96_vertices.tsv', 
-            package='networkDynamic'),,header=T)
+            package='networkDynamic'),header=TRUE,stringsAsFactors=FALSE)
 vertexData[1:5,] # peek
 edgeData <-read.table(system.file('extdata/cls33_10_16_96_edges.tsv', 
-            package='networkDynamic'),header=T)
+            package='networkDynamic'),header=TRUE,stringsAsFactors=FALSE)
 edgeData[1:5,] # peek
 
 
@@ -324,7 +324,15 @@ get.change.times(classDyn)[1:10]
 
 
 ###################################################
-### code chunk number 36: alterNetObs
+### code chunk number 36: assemble_mcfarland_TEA
+###################################################
+classDyn <- networkDynamic(vertex.spells=vertexData[,c(3,4,1)],
+              edge.spells=edgeData[,c(3,4,1,2,5,6)],
+              create.TEAs=TRUE,edge.TEA.names=c('weight','type'))
+
+
+###################################################
+### code chunk number 37: alterNetObs
 ###################################################
 nobs <-get.network.attribute(classDyn,'net.obs.period')
 names(nobs)
@@ -333,13 +341,13 @@ set.network.attribute(classDyn,'net.obs.period',nobs)
 
 
 ###################################################
-### code chunk number 37: mcfarland_vertattr
+### code chunk number 38: mcfarland_vertattr
 ###################################################
 nrow(vertexData)==length(unique(vertexData$vertex_id))
 
 
 ###################################################
-### code chunk number 38: mcfarland_vertexattr2
+### code chunk number 39: mcfarland_vertexattr2
 ###################################################
 set.vertex.attribute(classDyn,"data_id",vertexData$data_id)
 set.vertex.attribute(classDyn,"sex",as.character(vertexData$sex))
@@ -347,7 +355,7 @@ set.vertex.attribute(classDyn,"role",as.character(vertexData$role))
 
 
 ###################################################
-### code chunk number 39: classroom_binning
+### code chunk number 40: classroom_binning
 ###################################################
 classNets <- get.networks(classDyn,start=0,end=50,time.increment=5,rule='latest')
 classDensity <- sapply(classNets, network.density) 
@@ -355,7 +363,7 @@ plot(classDensity,type='l',xlab='network slice #',ylab='density')
 
 
 ###################################################
-### code chunk number 40: class_plots
+### code chunk number 41: class_plots
 ###################################################
 par(mfrow=c(2,2))   # show multiple plots
 plot(network.extract(
@@ -373,27 +381,27 @@ plot(network.extract(
 
 
 ###################################################
-### code chunk number 41: pids1
+### code chunk number 42: pids1
 ###################################################
 haystack<-network.initialize(30)
 activate.vertices(haystack,v=10:20)
 
 
 ###################################################
-### code chunk number 42: pids2
+### code chunk number 43: pids2
 ###################################################
 set.vertex.attribute(haystack,'needle',TRUE,v=sample(10:20,2))
 
 
 ###################################################
-### code chunk number 43: pids3
+### code chunk number 44: pids3
 ###################################################
 set.vertex.attribute(haystack,'hayId',paste('straw',1:30,sep=''))
 set.network.attribute(haystack,'vertex.pid','hayId')
 
 
 ###################################################
-### code chunk number 44: pids4
+### code chunk number 45: pids4
 ###################################################
 newstack<-network.extract(haystack,at=100,active.default=FALSE)
 network.size(newstack)
@@ -402,20 +410,20 @@ needleIds
 
 
 ###################################################
-### code chunk number 45: pids5
+### code chunk number 46: pids5
 ###################################################
 get.vertex.pid(newstack,needleIds)
 get.vertex.id(haystack,get.vertex.pid(newstack,needleIds))
 
 
 ###################################################
-### code chunk number 46: pids6
+### code chunk number 47: pids6
 ###################################################
 set.network.attribute(classDyn,'vertex.pid','data_id')
 
 
 ###################################################
-### code chunk number 47: nonpid_delete_example
+### code chunk number 48: nonpid_delete_example
 ###################################################
 net<-network.initialize(3)
 add.vertices(net,1)
@@ -425,7 +433,7 @@ as.matrix(net)
 
 
 ###################################################
-### code chunk number 48: pid_delete_example
+### code chunk number 49: pid_delete_example
 ###################################################
 net<-network.initialize(3)
 set.network.attribute(net,'vertex.pid','vertex.names')
@@ -436,7 +444,7 @@ as.matrix(net)
 
 
 ###################################################
-### code chunk number 49: initialize.pids
+### code chunk number 50: initialize.pids
 ###################################################
 net<-network.initialize(3)
 add.edges(net,tail=1:2,head=2:3)
@@ -446,41 +454,41 @@ net%e%'edge.pid'
 
 
 ###################################################
-### code chunk number 50: newcomb_spells
+### code chunk number 51: newcomb_spells
 ###################################################
 newcombEdgeSpells<-get.edge.activity(newcombDyn,as.spellList=TRUE)
 newcombEdgeSpells[1:5,] # peek at the beginning
 
 
 ###################################################
-### code chunk number 51: newcomb_dataframe
+### code chunk number 52: newcomb_dataframe
 ###################################################
 newcombEdgeSpells<-as.data.frame(newcombDyn)
 newcombEdgeSpells[1:5,] # peek at the beginning
 
 
 ###################################################
-### code chunk number 52: newcomb_vertspells
+### code chunk number 53: newcomb_vertspells
 ###################################################
 vertSpells <- get.vertex.activity(newcombDyn,as.spellList=TRUE)
 vertSpells[1:5,]
 
 
 ###################################################
-### code chunk number 53: slice_nets
+### code chunk number 54: slice_nets
 ###################################################
 lapply(get.networks(randomNet,start=0,end=2,time.increment=1),as.matrix)
 
 
 ###################################################
-### code chunk number 54: slice_nets2
+### code chunk number 55: slice_nets2
 ###################################################
 newSlices<-get.networks(newcombGaps)
 sapply(newSlices,network.size)
 
 
 ###################################################
-### code chunk number 55: tea1
+### code chunk number 56: tea1
 ###################################################
 net <-network.initialize(5)
 activate.vertex.attribute(net,"happiness", -1, onset=0,terminus=1)
@@ -492,7 +500,7 @@ get.vertex.attribute(net,"happiness.active",unlist=FALSE)[[1]]
 
 
 ###################################################
-### code chunk number 56: tea1.1
+### code chunk number 57: tea1.1
 ###################################################
 activate.network.attribute(net,'colors',"red",
                            onset=0,terminus=1)
@@ -504,7 +512,7 @@ activate.edge.attribute(net,'weight',c(1,2,1),onset=3,terminus=7)
 
 
 ###################################################
-### code chunk number 57: tea2
+### code chunk number 58: tea2
 ###################################################
 get.vertex.attribute.active(net,"happiness",at=3.5)
 get.vertex.attribute.active(net,"happiness",
@@ -514,13 +522,13 @@ get.vertex.attribute.active(net,"happiness",
 
 
 ###################################################
-### code chunk number 58: tea3
+### code chunk number 59: tea3
 ###################################################
 get.vertex.attribute.active(net,"happiness",onset=2.5,terminus=4.5)
 
 
 ###################################################
-### code chunk number 59: tea3_hidden
+### code chunk number 60: tea3_hidden
 ###################################################
 cat('Warning message:
 In get.vertex.attribute.active(net, "happiness", onset = 2.5, 
@@ -529,26 +537,26 @@ In get.vertex.attribute.active(net, "happiness", onset = 2.5,
 
 
 ###################################################
-### code chunk number 60: tea3.1
+### code chunk number 61: tea3.1
 ###################################################
 get.vertex.attribute.active(net,"happiness",onset=2.5,terminus=4.5,rule='earliest')
 
 
 ###################################################
-### code chunk number 61: tea3.2
+### code chunk number 62: tea3.2
 ###################################################
 get.vertex.attribute.active(net,"happiness",onset=2.5,terminus=4.5,rule='latest')
 
 
 ###################################################
-### code chunk number 62: tea4
+### code chunk number 63: tea4
 ###################################################
 get.vertex.attribute.active(net,"happiness",onset=2.5,terminus=4.5,
                         return.tea=TRUE)[[1]]
 
 
 ###################################################
-### code chunk number 63: tea5
+### code chunk number 64: tea5
 ###################################################
 sapply(get.vertex.attribute.active(net,"happiness",onset=0,terminus=7,
                   return.tea=TRUE),function(splist){
@@ -557,14 +565,14 @@ sapply(get.vertex.attribute.active(net,"happiness",onset=0,terminus=7,
 
 
 ###################################################
-### code chunk number 64: tea5.1
+### code chunk number 65: tea5.1
 ###################################################
 get.edge.attribute.active(net,'weight',at=2)
 get.edge.attribute.active(net,'weight',at=5)
 
 
 ###################################################
-### code chunk number 65: listtea
+### code chunk number 66: listtea
 ###################################################
 list.vertex.attributes.active(net,at=2)
 list.edge.attributes.active(net,at=2)
@@ -572,21 +580,21 @@ list.network.attributes.active(net,at=2,dynamic.only=TRUE)
 
 
 ###################################################
-### code chunk number 66: tea6
+### code chunk number 67: tea6
 ###################################################
 activate.vertex.attribute(net, "happiness",100, onset=0,terminus=10,v=1)
 get.vertex.attribute.active(net,"happiness",at=2)
 
 
 ###################################################
-### code chunk number 67: tea7
+### code chunk number 68: tea7
 ###################################################
 deactivate.vertex.attribute(net, "happiness",onset=1,terminus=10,v=2)
 get.vertex.attribute.active(net,"happiness",at=2)
 
 
 ###################################################
-### code chunk number 68: windsurfers
+### code chunk number 69: windsurfers
 ###################################################
 data(windsurfers)    # let's go to the beach!
 range(get.change.times(windsurfers))
@@ -595,7 +603,7 @@ sapply(0:31,function(t){ # how many people in net each day?
 
 
 ###################################################
-### code chunk number 69: windsurfers_meta
+### code chunk number 70: windsurfers_meta
 ###################################################
 list.network.attributes.active(windsurfers,-Inf,Inf,dynamic.only=TRUE)
 par(mfcol=c(2,1)) # show multiple plots
@@ -611,7 +619,7 @@ par(mfcol=c(1,1))
 
 
 ###################################################
-### code chunk number 70: windsurfers_meta2
+### code chunk number 71: windsurfers_meta2
 ###################################################
 day3 <-network.collapse(windsurfers,at=2)
 day3%n%'day' # what day of the week is day 3?
@@ -619,7 +627,7 @@ day3%n%'atmp' # air temp?
 
 
 ###################################################
-### code chunk number 71: windsim
+### code chunk number 72: windsim
 ###################################################
 runSim<-function(net,timeStep,transProb){
   # loop through time, updating states
@@ -657,13 +665,13 @@ runSim<-function(net,timeStep,transProb){
 
 
 ###################################################
-### code chunk number 72: setseed
+### code chunk number 73: setseed
 ###################################################
 set.seed(123) # so we will get the same results each time the document is built
 
 
 ###################################################
-### code chunk number 73: windsim_params
+### code chunk number 74: windsim_params
 ###################################################
 timeStep <- 1  # units are in days
 transProb <- 0.2 # how likely to tell in each conversation/day
@@ -676,7 +684,7 @@ windsurfers<-runSim(windsurfers,timeStep,transProb) # run it!
 
 
 ###################################################
-### code chunk number 74: windsim_plots
+### code chunk number 75: windsim_plots
 ###################################################
 par(mfcol=c(1,2)) # show two plots side by side
 wind7<-network.extract(windsurfers,at=7)
@@ -697,7 +705,7 @@ par(mfcol=c(1,1))
 
 
 ###################################################
-### code chunk number 75: windsim_stats
+### code chunk number 76: windsim_stats
 ###################################################
 get.vertex.attribute.active(windsurfers,'knowsRumor',at=15)
 plot(sapply(0:31,function(t){
@@ -708,7 +716,7 @@ plot(sapply(0:31,function(t){
 
 
 ###################################################
-### code chunk number 76: windsim_extract
+### code chunk number 77: windsim_extract
 ###################################################
 # pull TEA from v3, extract values from 1st part and unlist
 unlist(get.vertex.attribute.active(windsurfers,'heardRumorFrom',
@@ -719,7 +727,7 @@ get.vertex.attribute.active(windsurfers,'heardRumorFrom',
 
 
 ###################################################
-### code chunk number 77: windsim_tree
+### code chunk number 78: windsim_tree
 ###################################################
 transTree<-function(net){
   # for each vertex in net who knows
@@ -748,13 +756,13 @@ plot(transTree(windsurfers),displaylabels=TRUE,
 
 
 ###################################################
-### code chunk number 78: citation
+### code chunk number 79: citation
 ###################################################
 citation(package='networkDynamic')
 
 
 ###################################################
-### code chunk number 79: package_listing
+### code chunk number 80: package_listing
 ###################################################
 cat(ls("package:networkDynamic"),sep="\n")
 
